#line 1 "radius_dict.c"
/* Include this before everything else, for various large-file definitions */
#include "config.h"
#include <wireshark.h>

#line 6 "radius_dict.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define Radius__create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer Radius__create_buffer
#endif

#ifdef yy_delete_buffer
#define Radius__delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer Radius__delete_buffer
#endif

#ifdef yy_scan_buffer
#define Radius__scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer Radius__scan_buffer
#endif

#ifdef yy_scan_string
#define Radius__scan_string_ALREADY_DEFINED
#else
#define yy_scan_string Radius__scan_string
#endif

#ifdef yy_scan_bytes
#define Radius__scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes Radius__scan_bytes
#endif

#ifdef yy_init_buffer
#define Radius__init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer Radius__init_buffer
#endif

#ifdef yy_flush_buffer
#define Radius__flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer Radius__flush_buffer
#endif

#ifdef yy_load_buffer_state
#define Radius__load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state Radius__load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define Radius__switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer Radius__switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define Radius_push_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state Radius_push_buffer_state
#endif

#ifdef yypop_buffer_state
#define Radius_pop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state Radius_pop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define Radius_ensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack Radius_ensure_buffer_stack
#endif

#ifdef yylex
#define Radius_lex_ALREADY_DEFINED
#else
#define yylex Radius_lex
#endif

#ifdef yyrestart
#define Radius_restart_ALREADY_DEFINED
#else
#define yyrestart Radius_restart
#endif

#ifdef yylex_init
#define Radius_lex_init_ALREADY_DEFINED
#else
#define yylex_init Radius_lex_init
#endif

#ifdef yylex_init_extra
#define Radius_lex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra Radius_lex_init_extra
#endif

#ifdef yylex_destroy
#define Radius_lex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy Radius_lex_destroy
#endif

#ifdef yyget_debug
#define Radius_get_debug_ALREADY_DEFINED
#else
#define yyget_debug Radius_get_debug
#endif

#ifdef yyset_debug
#define Radius_set_debug_ALREADY_DEFINED
#else
#define yyset_debug Radius_set_debug
#endif

#ifdef yyget_extra
#define Radius_get_extra_ALREADY_DEFINED
#else
#define yyget_extra Radius_get_extra
#endif

#ifdef yyset_extra
#define Radius_set_extra_ALREADY_DEFINED
#else
#define yyset_extra Radius_set_extra
#endif

#ifdef yyget_in
#define Radius_get_in_ALREADY_DEFINED
#else
#define yyget_in Radius_get_in
#endif

#ifdef yyset_in
#define Radius_set_in_ALREADY_DEFINED
#else
#define yyset_in Radius_set_in
#endif

#ifdef yyget_out
#define Radius_get_out_ALREADY_DEFINED
#else
#define yyget_out Radius_get_out
#endif

#ifdef yyset_out
#define Radius_set_out_ALREADY_DEFINED
#else
#define yyset_out Radius_set_out
#endif

#ifdef yyget_leng
#define Radius_get_leng_ALREADY_DEFINED
#else
#define yyget_leng Radius_get_leng
#endif

#ifdef yyget_text
#define Radius_get_text_ALREADY_DEFINED
#else
#define yyget_text Radius_get_text
#endif

#ifdef yyget_lineno
#define Radius_get_lineno_ALREADY_DEFINED
#else
#define yyget_lineno Radius_get_lineno
#endif

#ifdef yyset_lineno
#define Radius_set_lineno_ALREADY_DEFINED
#else
#define yyset_lineno Radius_set_lineno
#endif

#ifdef yyget_column
#define Radius_get_column_ALREADY_DEFINED
#else
#define yyget_column Radius_get_column
#endif

#ifdef yyset_column
#define Radius_set_column_ALREADY_DEFINED
#else
#define yyset_column Radius_set_column
#endif

#ifdef yywrap
#define Radius_wrap_ALREADY_DEFINED
#else
#define yywrap Radius_wrap
#endif

#ifdef yyalloc
#define Radius_alloc_ALREADY_DEFINED
#else
#define yyalloc Radius_alloc
#endif

#ifdef yyrealloc
#define Radius_realloc_ALREADY_DEFINED
#else
#define yyrealloc Radius_realloc
#endif

#ifdef yyfree
#define Radius_free_ALREADY_DEFINED
#else
#define yyfree Radius_free
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define Radius_wrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 61
#define YY_END_OF_BUFFER 62
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[331] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       15,   15,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   17,   17,   62,   61,   60,    2,
        1,   61,    1,    1,   61,   61,   18,    1,   19,   19,
       30,    1,   31,   31,   49,    1,    1,   49,   49,   49,
       49,    1,   49,   49,   49,   54,   53,    1,   53,   53,
       55,    1,   56,   56,    2,    1,   57,   57,   59,    2,
        1,   61,    2,    1,   61,   12,    1,   14,   61,   15,

        2,    1,   29,   61,   25,   22,   26,   61,   27,   61,
       28,   16,    1,   17,    2,    1,    2,    0,    0,    0,
        0,    0,    0,   18,   19,    0,   30,   31,    0,   49,
       49,   49,   49,   49,   49,   49,   49,   49,   49,   49,
       49,   49,   49,   53,   52,   53,   53,   55,   56,    2,
       57,    0,   59,    2,    0,    0,    2,    2,    3,   12,
        0,   15,    2,    0,   23,   24,   16,   17,    2,    0,
        0,    0,    0,    0,    0,   20,   32,   49,   49,   49,
       49,   49,   49,   49,   49,   49,   49,   49,   49,   49,
       49,   48,   52,   53,   53,   58,    2,    0,    0,    0,

        0,    0,    0,    0,    0,   49,   44,   49,   40,   49,
       43,   49,   49,   49,   49,   49,   49,   49,   49,   53,
       53,    0,    0,    0,    0,    0,    0,    0,    6,    0,
       49,   49,   42,   49,   49,   49,   49,   49,   49,   45,
       49,   49,   53,   53,    0,    0,    0,    0,    0,    0,
        0,    4,   49,   49,   49,   36,   49,   49,   39,   35,
       46,   34,   53,   53,    0,    0,    0,    0,    0,    0,
       11,    0,   41,   49,   33,   49,   49,   53,   50,    0,
       21,    7,    0,    0,    0,    0,   47,   37,   49,   52,
       50,    0,    5,   10,    0,    0,   49,   51,    0,    0,

        9,   38,   51,    0,    0,    0,    8,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   13,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    1,    4,    5,    1,    1,    1,    1,
        1,    1,    1,    6,    7,    8,    9,   10,   11,   11,
       12,   13,   14,   15,   16,   16,   16,   17,    1,    1,
       18,    1,    1,    1,   19,   20,   21,   22,   23,   24,
       25,   26,   27,   28,   29,   30,   31,   32,   33,   34,
       35,   36,   37,   38,   39,   40,   28,   41,   42,   28,
        1,    1,    1,    1,   43,    1,   44,   45,   46,   47,

       48,   49,   50,   51,   52,   28,   29,   53,   54,   55,
       56,   57,   58,   59,   60,   61,   62,   63,   28,   64,
       65,   28,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[66] =
    {   0,
        1,    2,    3,    1,    1,    1,    4,    5,    6,    7,
        7,    7,    7,    7,    7,    7,    1,    8,    9,    9,
        9,    9,    9,    9,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
       10,    4,    4,    9,    9,    9,    9,    9,    9,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,   10,    4
    } ;

static const flex_int16_t yy_base[366] =
    {   0,
        0,   53,  106,    0,  169,  224,  275,    0,  338,  393,
        0,   23,  448,    0,  513,  568,  623,  678,  732,  786,
       11,   36,  840,  894,  947, 1003, 1061, 1116, 1169, 1216,
     1263, 1316, 1369, 1416,   51,   65,   89,  152,  194,  249,
      104,  129, 1465, 1520, 1573, 1626,  218, 1986, 1986,    0,
     1986,   32,   33,   64,   58,  105,    0,    0,  235,  169,
        0,    0,  292,   92,    0,   76,   92,  104,  103,  154,
      277,    0,  106,  298,  163, 1986,  184,  173,  185,  176,
        0,    0,    0,    0,    3,    0,  362,  350,    0,  188,
        0,  161,  176,  177,  238,    0,    0, 1986,  225,    0,

        0,    0, 1986,  241, 1986, 1986, 1986,   30, 1986,  236,
     1986,    0,    0,    0,    0,    0,    0,  278,  274,  242,
      299,  284,  290,    0,  374,    0,    0,  419,    0,    0,
      300,  290,  299,  293,  353,  353,  310,  515,  331,  368,
      356,  380,  377,  158,    0,  397,  382,    0,    0,   40,
      513,    0,    0,  146,  386,  505,  509,  548,  517,    0,
      545,    0,    0,  546, 1986, 1986,    0,    0,    0,  399,
      548,  538,  124,  553,  567,    0,    0,  563,  585,  589,
      587,  588,  598,  599,  610,  115,  605,  615,  603,  614,
      621,    0,    0,  641,  631,    0,  629,  634,  635,  640,

      623,  639,  652,  668,  668,  683,    0,  670,    0,  669,
        0,  679,  690,  698,  691,  680,  682,  696,  693,  688,
      720,  702,  721,  706,  727,   86,  720,  731, 1986,  721,
      723,   84,    0,  743,  724,  745,  727,  732,  734,    0,
      752,  750,  777,  778,  740,  746,  776,  763,  772,  764,
      777, 1986,  771,  793,  778,    0,  799,  801,    0,    0,
        0,    0,  790,  829,   51,   42,  815,  779,  799,  825,
     1986,  828,    0,  819,    0,  819,  832,   40,   68,  835,
     1986, 1986,  838,  824,  833,  833,    0,    0,  840,   77,
     1986,  827, 1986, 1986,  852,  835,  836,   22,  842,  849,

     1986,    0,    0,  867,  866,  872, 1986,  884,  884,  886,
       11,  872,  886,  885,  894,  886,  884,    2,  884,  888,
      905,  908,  903,  912,  910,  925,    0,  535, 1986, 1986,
     1681, 1691, 1701, 1711, 1721, 1731, 1741, 1751, 1761, 1771,
     1781, 1791, 1801, 1808, 1815, 1821, 1828, 1835, 1842, 1852,
     1862, 1872, 1882, 1892, 1902, 1909, 1919, 1929, 1936, 1946,
     1956, 1960, 1963, 1972, 1976
    } ;

static const flex_int16_t yy_def[366] =
    {   0,
      331,  331,  331,    3,  332,  332,    3,    7,  333,  333,
        7,    7,  330,   13,  334,  334,  335,  335,  336,  336,
        7,    7,  337,  337,  338,  338,  339,  339,    7,    7,
      340,  340,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,  341,  341,  342,  342,  330,  330,  330,  343,
      330,  330,  330,  330,  330,  330,  344,  344,  330,  330,
      345,  345,  330,  346,  347,  347,  347,  347,  347,  347,
      347,  347,  347,  347,  347,  330,  348,  348,  348,  348,
      349,  349,  350,  350,  351,  350,  330,  330,  352,  353,
      352,  354,  355,  354,  354,  356,  356,  330,  330,  357,

      358,  357,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  359,  359,  360,  361,  360,  343,  330,  330,  330,
      330,  330,  330,  344,  330,  362,  345,  330,  363,  347,
      347,  347,  347,  347,  347,  347,  347,  347,  347,  347,
      347,  347,  347,  348,  364,  348,  348,  349,  350,  351,
      330,  365,  352,  353,  354,  354,  355,  355,  354,  356,
      330,  357,  358,  330,  330,  330,  359,  360,  361,  330,
      330,  330,  330,  330,  330,  362,  363,  347,  347,  347,
      347,  347,  347,  347,  347,  347,  347,  347,  347,  347,
      347,  347,  364,  348,  348,  365,  355,  330,  330,  330,

      330,  330,  330,  330,  330,  347,  347,  347,  347,  347,
      347,  347,  347,  347,  347,  347,  347,  347,  347,  348,
      348,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      347,  347,  347,  347,  347,  347,  347,  347,  347,  347,
      347,  347,  348,  348,  330,  330,  330,  330,  330,  330,
      330,  330,  347,  347,  347,  347,  347,  347,  347,  347,
      347,  347,  348,  348,  330,  330,  330,  330,  330,  330,
      330,  330,  347,  347,  347,  347,  347,  348,  348,  330,
      330,  330,  330,  330,  330,  330,  347,  347,  347,  364,
      330,  330,  330,  330,  330,  330,  347,  364,  330,  330,

      330,  347,  364,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,    0,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330
    } ;

static const flex_int16_t yy_nxt[2052] =
    {   0,
      330,  330,   49,   50,  117,  149,  328,   63,  319,   64,
       63,   63,   63,   63,   63,   63,   51,  312,   51,   51,
       87,   88,   88,   88,   88,   88,   88,  303,   51,   51,
       63,   51,   64,   63,   63,   63,   63,   63,   63,  165,
      165,  117,  149,   51,   51,   87,   88,   88,   88,   88,
       88,   88,   51,  105,   51,   49,   50,  290,  118,  281,
       48,  106,   48,  106,   48,   48,   48,  105,  280,   51,
      119,   51,   51,  291,   48,  106,   48,  106,   48,   48,
       48,   51,   51,  118,   51,  145,  120,  298,  298,  121,
      254,  107,  249,  119,  108,  131,   51,   51,   48,   48,

       48,   48,   48,   48,   48,   51,  111,   51,   49,   50,
       52,  120,  121,   48,   48,   48,   48,   48,   48,   48,
      131,  134,   51,  122,   53,   54,  139,  123,   55,  214,
      203,  111,  129,  132,   51,   51,  133,   51,   48,   48,
       48,   48,   48,   48,   48,   56,  134,  117,  122,   53,
       54,  139,  123,   55,  107,  129,  132,  108,   51,  133,
       51,   48,   48,   48,   48,   48,   48,   48,   56,   48,
       48,   49,   50,   48,   48,  145,   48,   48,  125,  125,
      125,  125,  125,  125,  125,   51,   48,   58,   58,  117,
      145,  135,  143,  145,  147,  156,  109,   58,   58,  110,

       58,  145,  145,   48,   48,   48,   48,   48,   48,   48,
      158,  156,   58,   58,  135,  143,  146,  330,  156,  147,
      330,   58,  330,   58,   48,   48,   49,   50,   48,   48,
      330,   48,   48,  158,  156,  330,  330,  330,  330,  146,
       51,   48,   58,   58,  125,  125,  125,  125,  125,  125,
      125,  109,   58,   58,  110,   58,  166,  161,   48,   48,
       48,   48,   48,   48,   48,  330,  172,   58,   58,  159,
      330,  330,  156,  164,  330,  126,   58,  330,   58,   48,
      161,  166,  330,  330,   59,   60,   60,   60,   60,   60,
       60,  172,  159,   51,   51,  156,  164,   48,  126,  128,

      136,  128,  128,  128,  128,  128,  128,  128,  137,  170,
      138,  171,  330,  174,   48,  330,  330,  330,   51,   51,
      173,  175,   48,  140,  141,  136,  178,  179,  330,  180,
      181,  137,  170,  138,  171,  142,  174,   48,   48,   48,
       49,   50,   48,   48,  175,  173,  330,  184,  140,  141,
      179,  178,  180,  181,   51,   48,   62,   62,  142,  151,
      151,  151,  151,  151,  151,  151,   62,   62,  188,   62,
      184,  151,  151,  151,  151,  151,  151,  151,  182,  183,
      190,   62,   62,  125,  125,  125,  125,  125,  125,  125,
       62,  188,   62,   48,   48,   49,   50,   48,   48,  145,

      189,  330,  152,  182,  183,  190,  330,  330,  330,   51,
       48,   62,   62,  330,  145,  191,  192,  194,  195,  200,
      156,   62,   62,  189,   62,  152,  128,  330,  128,  128,
      128,  128,  128,  128,  128,  330,   62,   62,  191,  192,
      330,  195,  194,  156,  200,   62,  330,   62,   48,   48,
       49,   50,   48,   48,   65,   48,   48,   65,   65,   65,
       65,   65,   65,   65,   51,   48,   66,   67,   68,   69,
       70,   65,   65,   65,   71,   65,   72,   72,   65,   72,
       73,   65,   65,   65,   74,   75,   65,   65,   65,   65,
       65,   66,   67,   68,   69,   70,   65,   65,   65,   71,

       72,   65,   72,   73,   65,   65,   65,   74,   75,   65,
       65,   65,   65,   48,   48,   76,   50,   48,   48,  330,
       48,   48,  151,  151,  151,  151,  151,  151,  151,   51,
       48,   78,   78,  185,  330,   79,  159,  330,   80,  156,
      330,   78,   78,  158,   78,  329,  329,  329,  329,  329,
      330,  156,  330,  330,  186,  187,   78,   78,  185,  159,
       79,  330,  156,   80,  202,   78,  158,   78,   48,   48,
       76,   50,   48,   48,  156,   48,   48,  186,  187,  197,
      198,  199,  158,  201,   51,   48,   78,   78,  205,  202,
       79,  204,  330,   80,  206,  330,   78,   78,  330,   78,

      330,  330,  197,  198,  199,  158,  201,  207,  208,  209,
      210,   78,   78,  205,  204,   79,  330,  206,   80,  211,
       78,  212,   78,   48,   48,   49,   50,   48,   48,  330,
       48,  213,  207,  208,  209,  210,  215,  216,  217,   51,
       48,   82,   82,  330,  211,  218,  212,  219,  145,  225,
      330,   82,   82,  330,   82,  330,  213,  330,  145,  215,
      330,  217,  216,  158,  222,  223,   82,   82,  218,  224,
      226,  330,  219,  221,  225,   82,  220,   82,   48,   48,
       49,   50,   48,   48,  330,   48,  158,  222,  223,  227,
      229,  228,  224,  226,   51,   48,   82,   82,  330,  220,

      230,  231,  232,  234,  233,  145,   82,   82,  330,   82,
      330,  235,  227,  238,  228,  229,  236,  239,  241,  240,
      245,   82,   82,  230,  242,  232,  231,  233,  234,  243,
       82,  237,   82,   48,   84,   85,  235,  145,  238,  246,
      239,  236,  240,  241,  247,  245,  248,  242,   86,  250,
       86,   86,  243,  251,  237,  330,  252,  244,  253,  256,
       86,   86,  258,   86,  246,  255,  257,  247,  330,  259,
      260,  248,  250,  261,  262,   86,   86,  265,  251,  252,
      244,  253,  256,  266,   86,  258,   86,   48,   84,   85,
      255,  257,  259,  260,  145,  145,  264,  267,  261,  262,

      265,  268,   86,  271,   86,   86,  266,  145,  272,  269,
      263,  270,  273,  275,   86,   86,  283,   86,  330,  274,
      276,  264,  267,  277,  268,  330,  271,  278,  284,   86,
       86,  272,  269,  263,  270,  273,  275,  282,   86,  283,
       86,   48,   49,   90,  274,  276,  145,  285,  277,  286,
      278,  284,  287,  279,  288,  289,   91,  292,   91,   91,
      293,  330,  282,  294,  295,  296,  297,  299,   91,   91,
      301,   91,  285,  300,  286,  287,  302,  288,  279,  304,
      289,  305,  292,   91,   91,  293,  294,  295,  296,  306,
      299,  297,   91,  301,   91,   48,   49,   90,  300,  302,

      330,  307,  304,  308,  305,  309,  310,  311,  314,  330,
       91,  313,   91,   91,  306,  316,  315,  330,  317,  318,
      320,  321,   91,   91,  307,   91,  308,  322,  323,  324,
      309,  310,  311,  314,  313,  325,  326,   91,   91,  315,
      316,  317,  318,  320,  321,  327,   91,  330,   91,   49,
       93,  330,  322,  323,  324,  330,  330,  330,  330,  330,
      325,  326,  330,   94,  330,   94,   94,  330,  330,  330,
      327,  330,  330,  330,  330,   94,   94,  330,   94,  330,
      330,   95,  330,  330,  330,  330,  330,  330,  330,  330,
       94,   94,  330,  330,  330,  330,  330,  330,  330,   94,

      330,   94,  330,  330,   95,   49,   93,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,   94,
      330,   94,   94,  330,  330,  330,  330,  330,  330,  330,
      330,   94,   94,  330,   94,  330,  330,   95,  330,  330,
      330,  330,  330,  330,  330,  330,   94,   94,  330,  330,
      330,  330,  330,  330,  330,   94,  330,   94,  330,  330,
       95,   48,   48,   49,   50,   48,   48,  330,   48,   48,
      330,  330,  330,  330,  330,  330,  330,   51,   48,   97,
       97,  330,  330,  330,  330,  330,  330,  330,  330,   97,
       97,  330,   97,  330,  330,  330,  330,  330,  330,  330,

      330,  330,  330,  330,   97,   97,  330,  330,  330,  330,
      330,  330,  330,   97,  330,   97,   48,   48,   49,   50,
       48,   48,  330,   48,   48,  330,  330,  330,  330,  330,
      330,  330,   51,   48,   97,   97,  330,  330,  330,  330,
      330,  330,  330,  330,   97,   97,  330,   97,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,   97,
       97,  330,  330,  330,  330,  330,  330,  330,   97,  330,
       97,   98,  330,  330,  330,  330,  330,  330,   48,   48,
       48,   48,   48,   48,   48,  330,  330,  330,  330,  330,
      330,  330,   99,  330,  330,  330,  330,  330,  330,  330,

      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,   99,   98,  330,
      330,  330,  330,  330,  330,   48,   48,   48,   48,   48,
       48,   48,  330,  330,  330,  330,  330,  330,  330,   99,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  330,   99,   49,  101,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  102,
      330,  102,  102,  330,  330,  330,  330,  330,  330,  330,
      330,  102,  102,  330,  102,  330,  330,  330,  330,  330,

      330,  330,  330,  330,  330,  330,  102,  102,  330,  330,
      330,  330,  330,  330,  330,  102,  330,  102,   49,  101,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  102,  330,  102,  102,  330,  330,  330,  330,
      330,  330,  330,  330,  102,  102,  330,  102,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  102,
      102,  330,  330,  330,  330,  330,  330,  330,  102,  330,
      102,  103,  330,  330,  330,  330,  330,  330,   48,   48,
       48,   48,   48,   48,   48,  330,  330,  330,  330,  330,
      330,  330,  104,  330,  330,  330,  330,  330,  330,  330,

      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  104,  103,  330,
      330,  330,  330,  330,  330,   48,   48,   48,   48,   48,
       48,   48,  330,  330,  330,  330,  330,  330,  330,  104,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  104,   48,   48,   49,   50,   48,
       48,  330,   48,   48,  330,  330,  330,  330,  330,  330,
      330,   51,   48,  113,  113,  330,  330,  330,  330,  330,
      330,  330,  330,  113,  113,  330,  113,  330,  330,  330,

      330,  330,  330,  330,  330,  330,  330,  330,  113,  113,
      330,  330,  330,  330,  330,  330,  330,  113,  330,  113,
       48,   48,   49,   50,   48,   48,  330,   48,   48,  330,
      330,  330,  330,  330,  330,  330,   51,   48,  113,  113,
      330,  330,  330,  330,  330,  330,  330,  330,  113,  113,
      330,  113,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  113,  113,  330,  330,  330,  330,  330,
      330,  330,  113,  330,  113,   49,  115,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  116,
      330,  116,  116,  330,  330,  330,  330,  330,  330,  330,

      330,  116,  116,  330,  116,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  116,  116,  330,  330,
      330,  330,  330,  330,  330,  116,  330,  116,   49,  115,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  116,  330,  116,  116,  330,  330,  330,  330,
      330,  330,  330,  330,  116,  116,  330,  116,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  116,
      116,  330,  330,  330,  330,  330,  330,  330,  116,  330,
      116,   48,   48,   48,   48,   48,   48,   48,   48,   48,
       48,   57,   57,   57,   57,   57,   57,   57,   57,   57,

       57,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   77,   77,   77,   77,   77,   77,   77,   77,   77,
       77,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   83,   83,   83,   83,   83,   83,   83,   83,   83,
       83,   89,   89,   89,   89,   89,   89,   89,   89,   89,
       89,   92,   92,   92,   92,   92,   92,   92,   92,   92,
       92,   96,   96,   96,   96,   96,   96,   96,   96,   96,
       96,  100,  100,  100,  100,  100,  100,  100,  100,  100,
      100,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  114,  114,  114,  114,  114,  114,  114,  114,  114,

      114,  117,  117,  330,  117,  117,  117,  117,  117,  117,
      117,  124,  330,  330,  124,  330,  124,  124,  127,  127,
      127,  127,  330,  127,  127,  128,  330,  128,  330,  330,
      128,  130,  330,  330,  130,  330,  130,  130,  144,  330,
      330,  144,  144,  144,  144,  148,  330,  148,  148,  330,
      148,  148,  149,  330,  149,  149,  149,  149,  149,  149,
      149,  149,  150,  150,  150,  150,  150,  150,  150,  150,
      150,  150,  153,  330,  330,  153,  153,  153,  153,  153,
      153,  153,  154,  154,  330,  154,  154,  154,  154,  154,
      154,  154,  155,  155,  330,  155,  155,  155,  155,  155,

      155,  155,  157,  157,  330,  157,  157,  157,  157,  157,
      157,  157,  160,  330,  330,  160,  330,  160,  160,  162,
      162,  330,  162,  162,  162,  162,  162,  162,  162,  163,
      163,  330,  163,  163,  163,  163,  163,  163,  163,  167,
      330,  330,  167,  330,  167,  167,  168,  168,  330,  168,
      168,  168,  168,  168,  168,  168,  169,  169,  330,  169,
      169,  169,  169,  169,  169,  169,  176,  330,  176,  177,
      330,  177,  193,  193,  330,  193,  193,  193,  193,  193,
      193,  193,  196,  330,  196,   47,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,

      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330
    } ;

static const flex_int16_t yy_chk[2052] =
    {   0,
        0,    0,    1,    1,   85,   85,  327,   11,  318,   11,
       11,   11,   11,   11,   11,   11,    1,  311,    1,    1,
       21,   21,   21,   21,   21,   21,   21,  298,    1,    1,
       12,    1,   12,   12,   12,   12,   12,   12,   12,  108,
      108,  150,  150,    1,    1,   22,   22,   22,   22,   22,
       22,   22,    1,   35,    1,    2,    2,  278,   52,  266,
       35,   35,   35,   35,   35,   35,   35,   36,  265,    2,
       53,    2,    2,  279,   36,   36,   36,   36,   36,   36,
       36,    2,    2,   52,    2,  279,   54,  290,  290,   55,
      232,   37,  226,   53,   37,   66,    2,    2,   37,   37,

       37,   37,   37,   37,   37,    2,   41,    2,    3,    3,
        3,   54,   55,   41,   41,   41,   41,   41,   41,   41,
       66,   69,    3,   56,    3,    3,   73,   56,    3,  186,
      173,   42,   64,   67,    3,    3,   68,    3,   42,   42,
       42,   42,   42,   42,   42,    3,   69,  154,   56,    3,
        3,   73,   56,    3,   38,   64,   67,   38,    3,   68,
        3,   38,   38,   38,   38,   38,   38,   38,    3,    5,
        5,    5,    5,    5,    5,  144,    5,    5,   60,   60,
       60,   60,   60,   60,   60,    5,    5,    5,    5,   90,
       78,   70,   75,   80,   80,   92,   39,    5,    5,   39,

        5,   77,   79,   39,   39,   39,   39,   39,   39,   39,
       93,   94,    5,    5,   70,   75,   79,   47,   92,   80,
        0,    5,    0,    5,    6,    6,    6,    6,    6,    6,
        0,    6,    6,   93,   94,    0,    0,    0,    0,   79,
        6,    6,    6,    6,   59,   59,   59,   59,   59,   59,
       59,   40,    6,    6,   40,    6,  110,   99,   40,   40,
       40,   40,   40,   40,   40,    0,  120,    6,    6,   95,
        0,    0,   95,  104,    0,   59,    6,    0,    6,    7,
       99,  110,    0,    0,    7,    7,    7,    7,    7,    7,
        7,  120,   95,    7,    7,   95,  104,    7,   59,   63,

       71,   63,   63,   63,   63,   63,   63,   63,   71,  118,
       71,  119,    0,  122,    7,    0,    0,    0,    7,    7,
      121,  123,    7,   74,   74,   71,  131,  132,    0,  133,
      134,   71,  118,   71,  119,   74,  122,    7,    9,    9,
        9,    9,    9,    9,  123,  121,    0,  137,   74,   74,
      132,  131,  133,  134,    9,    9,    9,    9,   74,   88,
       88,   88,   88,   88,   88,   88,    9,    9,  139,    9,
      137,   87,   87,   87,   87,   87,   87,   87,  135,  136,
      141,    9,    9,  125,  125,  125,  125,  125,  125,  125,
        9,  139,    9,   10,   10,   10,   10,   10,   10,  147,

      140,    0,   87,  135,  136,  141,    0,    0,    0,   10,
       10,   10,   10,    0,  146,  142,  143,  146,  147,  170,
      155,   10,   10,  140,   10,   87,  128,    0,  128,  128,
      128,  128,  128,  128,  128,    0,   10,   10,  142,  143,
        0,  147,  146,  155,  170,   10,    0,   10,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,

       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   15,   15,   15,   15,   15,   15,    0,
       15,   15,  151,  151,  151,  151,  151,  151,  151,   15,
       15,   15,   15,  138,    0,   15,  156,    0,   15,  156,
        0,   15,   15,  157,   15,  328,  328,  328,  328,  328,
        0,  159,    0,    0,  138,  138,   15,   15,  138,  156,
       15,    0,  156,   15,  172,   15,  157,   15,   16,   16,
       16,   16,   16,   16,  159,   16,   16,  138,  138,  158,
      161,  164,  158,  171,   16,   16,   16,   16,  175,  172,
       16,  174,    0,   16,  178,    0,   16,   16,    0,   16,

        0,    0,  158,  161,  164,  158,  171,  179,  180,  181,
      182,   16,   16,  175,  174,   16,    0,  178,   16,  183,
       16,  184,   16,   17,   17,   17,   17,   17,   17,    0,
       17,  185,  179,  180,  181,  182,  187,  188,  189,   17,
       17,   17,   17,    0,  183,  190,  184,  191,  195,  201,
        0,   17,   17,    0,   17,    0,  185,    0,  194,  187,
        0,  189,  188,  197,  198,  199,   17,   17,  190,  200,
      202,    0,  191,  195,  201,   17,  194,   17,   18,   18,
       18,   18,   18,   18,    0,   18,  197,  198,  199,  203,
      204,  203,  200,  202,   18,   18,   18,   18,    0,  194,

      205,  206,  208,  212,  210,  220,   18,   18,    0,   18,
        0,  213,  203,  215,  203,  204,  214,  216,  218,  217,
      222,   18,   18,  205,  219,  208,  206,  210,  212,  220,
       18,  214,   18,   19,   19,   19,  213,  221,  215,  223,
      216,  214,  217,  218,  224,  222,  225,  219,   19,  227,
       19,   19,  220,  228,  214,    0,  230,  221,  231,  235,
       19,   19,  237,   19,  223,  234,  236,  224,    0,  238,
      239,  225,  227,  241,  242,   19,   19,  245,  228,  230,
      221,  231,  235,  246,   19,  237,   19,   20,   20,   20,
      234,  236,  238,  239,  243,  244,  244,  247,  241,  242,

      245,  248,   20,  250,   20,   20,  246,  263,  251,  249,
      243,  249,  253,  255,   20,   20,  268,   20,    0,  254,
      257,  244,  247,  258,  248,    0,  250,  263,  269,   20,
       20,  251,  249,  243,  249,  253,  255,  267,   20,  268,
       20,   23,   23,   23,  254,  257,  264,  270,  258,  272,
      263,  269,  274,  264,  276,  277,   23,  280,   23,   23,
      283,    0,  267,  284,  285,  286,  289,  292,   23,   23,
      296,   23,  270,  295,  272,  274,  297,  276,  264,  299,
      277,  300,  280,   23,   23,  283,  284,  285,  286,  304,
      292,  289,   23,  296,   23,   24,   24,   24,  295,  297,

        0,  305,  299,  306,  300,  308,  309,  310,  313,    0,
       24,  312,   24,   24,  304,  315,  314,    0,  316,  317,
      319,  320,   24,   24,  305,   24,  306,  321,  322,  323,
      308,  309,  310,  313,  312,  324,  325,   24,   24,  314,
      315,  316,  317,  319,  320,  326,   24,    0,   24,   25,
       25,    0,  321,  322,  323,    0,    0,    0,    0,    0,
      324,  325,    0,   25,    0,   25,   25,    0,    0,    0,
      326,    0,    0,    0,    0,   25,   25,    0,   25,    0,
        0,   25,    0,    0,    0,    0,    0,    0,    0,    0,
       25,   25,    0,    0,    0,    0,    0,    0,    0,   25,

        0,   25,    0,    0,   25,   26,   26,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   26,
        0,   26,   26,    0,    0,    0,    0,    0,    0,    0,
        0,   26,   26,    0,   26,    0,    0,   26,    0,    0,
        0,    0,    0,    0,    0,    0,   26,   26,    0,    0,
        0,    0,    0,    0,    0,   26,    0,   26,    0,    0,
       26,   27,   27,   27,   27,   27,   27,    0,   27,   27,
        0,    0,    0,    0,    0,    0,    0,   27,   27,   27,
       27,    0,    0,    0,    0,    0,    0,    0,    0,   27,
       27,    0,   27,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,   27,   27,    0,    0,    0,    0,
        0,    0,    0,   27,    0,   27,   28,   28,   28,   28,
       28,   28,    0,   28,   28,    0,    0,    0,    0,    0,
        0,    0,   28,   28,   28,   28,    0,    0,    0,    0,
        0,    0,    0,    0,   28,   28,    0,   28,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   28,
       28,    0,    0,    0,    0,    0,    0,    0,   28,    0,
       28,   29,    0,    0,    0,    0,    0,    0,   29,   29,
       29,   29,   29,   29,   29,    0,    0,    0,    0,    0,
        0,    0,   29,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   29,   30,    0,
        0,    0,    0,    0,    0,   30,   30,   30,   30,   30,
       30,   30,    0,    0,    0,    0,    0,    0,    0,   30,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   30,   31,   31,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   31,
        0,   31,   31,    0,    0,    0,    0,    0,    0,    0,
        0,   31,   31,    0,   31,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,   31,   31,    0,    0,
        0,    0,    0,    0,    0,   31,    0,   31,   32,   32,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   32,    0,   32,   32,    0,    0,    0,    0,
        0,    0,    0,    0,   32,   32,    0,   32,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   32,
       32,    0,    0,    0,    0,    0,    0,    0,   32,    0,
       32,   33,    0,    0,    0,    0,    0,    0,   33,   33,
       33,   33,   33,   33,   33,    0,    0,    0,    0,    0,
        0,    0,   33,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   33,   34,    0,
        0,    0,    0,    0,    0,   34,   34,   34,   34,   34,
       34,   34,    0,    0,    0,    0,    0,    0,    0,   34,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   34,   43,   43,   43,   43,   43,
       43,    0,   43,   43,    0,    0,    0,    0,    0,    0,
        0,   43,   43,   43,   43,    0,    0,    0,    0,    0,
        0,    0,    0,   43,   43,    0,   43,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,   43,   43,
        0,    0,    0,    0,    0,    0,    0,   43,    0,   43,
       44,   44,   44,   44,   44,   44,    0,   44,   44,    0,
        0,    0,    0,    0,    0,    0,   44,   44,   44,   44,
        0,    0,    0,    0,    0,    0,    0,    0,   44,   44,
        0,   44,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   44,   44,    0,    0,    0,    0,    0,
        0,    0,   44,    0,   44,   45,   45,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   45,
        0,   45,   45,    0,    0,    0,    0,    0,    0,    0,

        0,   45,   45,    0,   45,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   45,   45,    0,    0,
        0,    0,    0,    0,    0,   45,    0,   45,   46,   46,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   46,    0,   46,   46,    0,    0,    0,    0,
        0,    0,    0,    0,   46,   46,    0,   46,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   46,
       46,    0,    0,    0,    0,    0,    0,    0,   46,    0,
       46,  331,  331,  331,  331,  331,  331,  331,  331,  331,
      331,  332,  332,  332,  332,  332,  332,  332,  332,  332,

      332,  333,  333,  333,  333,  333,  333,  333,  333,  333,
      333,  334,  334,  334,  334,  334,  334,  334,  334,  334,
      334,  335,  335,  335,  335,  335,  335,  335,  335,  335,
      335,  336,  336,  336,  336,  336,  336,  336,  336,  336,
      336,  337,  337,  337,  337,  337,  337,  337,  337,  337,
      337,  338,  338,  338,  338,  338,  338,  338,  338,  338,
      338,  339,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  340,  340,  340,  340,  340,  340,  340,  340,  340,
      340,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  342,  342,  342,  342,  342,  342,  342,  342,  342,

      342,  343,  343,    0,  343,  343,  343,  343,  343,  343,
      343,  344,    0,    0,  344,    0,  344,  344,  345,  345,
      345,  345,    0,  345,  345,  346,    0,  346,    0,    0,
      346,  347,    0,    0,  347,    0,  347,  347,  348,    0,
        0,  348,  348,  348,  348,  349,    0,  349,  349,    0,
      349,  349,  350,    0,  350,  350,  350,  350,  350,  350,
      350,  350,  351,  351,  351,  351,  351,  351,  351,  351,
      351,  351,  352,    0,    0,  352,  352,  352,  352,  352,
      352,  352,  353,  353,    0,  353,  353,  353,  353,  353,
      353,  353,  354,  354,    0,  354,  354,  354,  354,  354,

      354,  354,  355,  355,    0,  355,  355,  355,  355,  355,
      355,  355,  356,    0,    0,  356,    0,  356,  356,  357,
      357,    0,  357,  357,  357,  357,  357,  357,  357,  358,
      358,    0,  358,  358,  358,  358,  358,  358,  358,  359,
        0,    0,  359,    0,  359,  359,  360,  360,    0,  360,
      360,  360,  360,  360,  360,  360,  361,  361,    0,  361,
      361,  361,  361,  361,  361,  361,  362,    0,  362,  363,
        0,  363,  364,  364,    0,  364,  364,  364,  364,  364,
      364,  364,  365,    0,  365,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,

      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"

/*
 * We want a reentrant scanner.
 */
/*
 * We don't use input, so don't generate code for it.
 */
#define YY_NO_INPUT 1
/*
 * We don't use unput, so don't generate code for it.
 */
/*
 * We don't read interactively from the terminal.
 */
/*
 * We want to stop processing when we get to the end of the input.
 */
/*
 * The language we're scanning is case-insensitive.
 */
/*
 * The type for the state we keep for a scanner.
 */
/*
 * We have to override the memory allocators so that we don't get
 * "unused argument" warnings from the yyscanner argument (which
 * we don't use, as we have a global memory allocator).
 *
 * We provide, as macros, our own versions of the routines generated by Flex,
 * which just call malloc()/realloc()/free() (as the Flex versions do),
 * discarding the extra argument.
 */
/*
 * Prefix scanner routines with "Radius_" rather than "yy", so this scanner
 * can coexist with other scanners.
 */
#line 64 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
	/* radius_dict.l
	*
	* RADIUS dictionary parser
	*
	* Wireshark - Network traffic analyzer
	* By Gerald Combs <gerald@wireshark.org>
	* Copyright 1998 Gerald Combs
	*
	* This program is free software; you can redistribute it and/or
	* modify it under the terms of the GNU General Public License
	* as published by the Free Software Foundation; either version 2
	* of the License, or (at your option) any later version.
	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

#include <glib.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <epan/packet.h>
#include <epan/dissectors/packet-radius.h>
#include <wsutil/file_util.h>

/*
 * Disable diagnostics in the code generated by Flex.
 */
DIAG_OFF_FLEX

/*
 * See
 *
 *	http://freeradius.org/radiusd/man/dictionary.html
 *
 * for the format of RADIUS dictionary files.
 *
 * XXX - features not currently supported:
 *
 *	integer64, ipv4prefix, combo-prefix, bool, size, decimal,
 *	timeval, struct, extended, long-extended, vsa, evs, vendor,
 *	cidr, uint{8,16,32,64}, int{8,16,32,64} as attribute types
 *	(some of these aren't documented);
 *
 *	octets[N], where N is an integer, as an attribute type
 *	(not documented in the man page);
 *
 *	internal, array, concat, and virtual as attribute flags (not
 *	documented in the man page);
 *
 * We should, perhaps, adopt FreeRADIUS's dictionary-parsing code in
 * src/lib/dict.c and use that, rather than writing our own parser.
 * See bug 13176.
 */
#define YY_USER_INIT BEGIN WS_OUT;

#define ECHO
#define MAX_INCLUDE_DEPTH 10

typedef struct {
	YY_BUFFER_STATE include_stack[MAX_INCLUDE_DEPTH];
	int include_stack_ptr;

	radius_dictionary_t* dict;
	GHashTable* value_strings; /* GArray(value_string) by attribute name */

	gchar* attr_name;
	gchar* attr_id;
	radius_attr_dissector_t* attr_type;
	gchar* attr_vendor;
	gchar* vendor_name;
	guint32 vendor_id;
	guint vendor_type_octets;
	guint vendor_length_octets;
	gboolean vendor_has_flags;
	gchar* value_repr;
	guint encrypted;
	gboolean has_tag;
	gchar* current_vendor;
	guint current_vendor_evs_type;
	gchar* current_attr;

	gchar* directory;
	gchar* fullpaths[MAX_INCLUDE_DEPTH];
	int linenums[MAX_INCLUDE_DEPTH];

	GString* error;
} Radius_scanner_state_t;

static void add_vendor(Radius_scanner_state_t* state, const gchar* name, guint32 id, guint type_octets, guint length_octets, gboolean has_flags);
static gboolean add_attribute(Radius_scanner_state_t* state, const gchar*,const  gchar*, radius_attr_dissector_t,const  gchar*, guint, gboolean, const gchar*);
static gboolean add_tlv(Radius_scanner_state_t* state, const gchar* name, const  gchar* code, radius_attr_dissector_t type, const gchar* attr);
static void add_value(Radius_scanner_state_t* state, const gchar* attrib_name, const  gchar* repr, guint32 value);

/*
 * Sleazy hack to suppress compiler warnings in yy_fatal_error().
 */
#define YY_EXIT_FAILURE ((void)yyscanner, 2)

/*
 * Macros for the allocators, to discard the extra argument.
 */
#define Radius_alloc(size, yyscanner)		(void *)malloc(size)
#define Radius_realloc(ptr, size, yyscanner)	(void *)realloc((char *)(ptr), (size))
#define Radius_free(ptr, yyscanner)		free((char *)ptr)

#line 1353 "radius_dict.c"
/* Note: FreeRadius allows VENDOR, ATTRIBUTE and VALUE names to contain any non-blank character.
 *       Using a negated "blank character class" pattern below for those names fails for some reason
 *       so for now the patterns for each name type include those characters found for the corresponding
 *       name types in the FreeRadius dictionaries.
 */

#line 1360 "radius_dict.c"

#define INITIAL 0
#define WS_OUT 1
#define VENDOR 2
#define VENDOR_W_NAME 3
#define ATTR 4
#define ATTR_W_NAME 5
#define ATTR_W_ID 6
#define ATTR_W_TYPE 7
#define VALUE 8
#define VALUE_W_ATTR 9
#define VALUE_W_NAME 10
#define INCLUDE 11
#define JUNK 12
#define BEGIN_VENDOR 13
#define BEGIN_VENDOR_FORMAT 14
#define END_VENDOR 15
#define VENDOR_W_ID 16
#define VENDOR_W_FORMAT 17
#define VENDOR_W_TYPE_OCTETS 18
#define VENDOR_W_LENGTH_OCTETS 19
#define VENDOR_W_CONTINUATION 20
#define BEGIN_TLV 21
#define END_TLV 22

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#define YY_EXTRA_TYPE Radius_scanner_state_t*

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (yyscan_t yyscanner);

#define YY_DECL int yylex (yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 186 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"

#line 1640 "radius_dict.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 331 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 330 );
		yy_cp = yyg->yy_last_accepting_cpos;
		yy_current_state = yyg->yy_last_accepting_state;

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 187 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
;
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 188 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
;
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 190 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
;
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 192 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ BEGIN VENDOR; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 193 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ BEGIN ATTR; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 194 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ BEGIN VALUE; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 195 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ BEGIN INCLUDE; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 196 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ BEGIN BEGIN_VENDOR; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 197 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ BEGIN END_VENDOR; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 198 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ BEGIN BEGIN_TLV; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 199 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ BEGIN END_TLV; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 201 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{
    if (yyextra->current_vendor) {
        g_free(yyextra->current_vendor);
    }
    yyextra->current_vendor = g_strdup(yytext);
    BEGIN BEGIN_VENDOR_FORMAT;
}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 208 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{
    if (strcmp(yytext, "format=Extended-Vendor-Specific-1") == 0) {
        yyextra->current_vendor_evs_type = 241;
    } else if(strcmp(yytext, "format=Extended-Vendor-Specific-2") == 0) {
        yyextra->current_vendor_evs_type = 242;
    } else if(strcmp(yytext, "format=Extended-Vendor-Specific-3") == 0) {
        yyextra->current_vendor_evs_type = 243;
    } else if(strcmp(yytext, "format=Extended-Vendor-Specific-4") == 0) {
        yyextra->current_vendor_evs_type = 244;
    } else if(strcmp(yytext, "format=Extended-Vendor-Specific-5") == 0) {
        yyextra->current_vendor_evs_type = 245;
    } else if(strcmp(yytext, "format=Extended-Vendor-Specific-6") == 0) {
        yyextra->current_vendor_evs_type = 246;
    }
    BEGIN WS_OUT;
}
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 224 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{BEGIN WS_OUT;}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 226 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{
    if (yyextra->current_vendor) {
        g_free(yyextra->current_vendor);
        yyextra->current_vendor = NULL;
    }
    yyextra->current_vendor_evs_type = 0;
    BEGIN WS_OUT;
}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 235 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{
    if (yyextra->current_attr) {
        g_free(yyextra->current_attr);
    }
    yyextra->current_attr = g_strdup(yytext);
    BEGIN WS_OUT;
}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 242 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{
    if (yyextra->current_attr) {
        g_free(yyextra->current_attr);
        yyextra->current_attr = NULL;
    }
    BEGIN WS_OUT;
}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 250 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{
    yyextra->vendor_name = g_strdup(yytext);
    yyextra->vendor_type_octets = 1;
    yyextra->vendor_length_octets = 1;
    yyextra->vendor_has_flags = FALSE;
    BEGIN VENDOR_W_NAME;
}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 257 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{
    yyextra->vendor_id = (guint32) strtoul(yytext,NULL,10);
    BEGIN VENDOR_W_ID;
}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 261 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{
    yyextra->vendor_id = (guint32) strtoul(yytext,NULL,16);
    BEGIN VENDOR_W_ID;
}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 265 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{
    BEGIN VENDOR_W_FORMAT;
}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 268 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{
    yyextra->vendor_type_octets = (guint) strtoul(yytext,NULL,10);
    BEGIN VENDOR_W_TYPE_OCTETS;
}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 272 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{
    yyextra->vendor_length_octets = (guint) strtoul(yytext+1,NULL,10);
    BEGIN VENDOR_W_LENGTH_OCTETS;
}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 276 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{
    yyextra->vendor_has_flags = TRUE;
    BEGIN VENDOR_W_CONTINUATION;
}
	YY_BREAK
case 25:
/* rule 25 can match eol */
#line 281 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
case 26:
/* rule 26 can match eol */
#line 282 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
case 27:
/* rule 27 can match eol */
#line 283 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
case 28:
/* rule 28 can match eol */
#line 284 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
case 29:
/* rule 29 can match eol */
YY_RULE_SETUP
#line 284 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{
    add_vendor(yyextra, yyextra->vendor_name, yyextra->vendor_id, yyextra->vendor_type_octets, yyextra->vendor_length_octets, yyextra->vendor_has_flags);
    g_free(yyextra->vendor_name);
    BEGIN WS_OUT;
}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 290 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->attr_name = g_strdup(yytext); yyextra->encrypted = 0; yyextra->has_tag = FALSE; BEGIN ATTR_W_NAME; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 291 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->attr_id = g_strdup(yytext);  BEGIN ATTR_W_ID;}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 292 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->attr_id = ws_strdup_printf("%u",(int)strtoul(yytext,NULL,16)); BEGIN ATTR_W_ID;}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 293 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->attr_type = radius_integer;  BEGIN ATTR_W_TYPE; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 294 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->attr_type = radius_string;  BEGIN ATTR_W_TYPE; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 295 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->attr_type = radius_octets;  BEGIN ATTR_W_TYPE; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 296 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->attr_type = radius_ipaddr;  BEGIN ATTR_W_TYPE; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 297 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->attr_type = radius_ipv6addr;  BEGIN ATTR_W_TYPE; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 298 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->attr_type = radius_ipv6prefix;  BEGIN ATTR_W_TYPE; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 299 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->attr_type = radius_ipxnet;  BEGIN ATTR_W_TYPE; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 300 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->attr_type = radius_date;  BEGIN ATTR_W_TYPE; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 301 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->attr_type = radius_abinary;  BEGIN ATTR_W_TYPE; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 302 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->attr_type = radius_ether;  BEGIN ATTR_W_TYPE; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 303 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->attr_type = radius_ifid;  BEGIN ATTR_W_TYPE; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 304 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->attr_type = radius_integer;  BEGIN ATTR_W_TYPE; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 305 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->attr_type = radius_integer;  BEGIN ATTR_W_TYPE; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 306 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->attr_type = radius_signed;  BEGIN ATTR_W_TYPE; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 307 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->attr_type = radius_combo_ip;  BEGIN ATTR_W_TYPE; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 308 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->attr_type = radius_tlv;  BEGIN ATTR_W_TYPE; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 309 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->attr_type = radius_octets;  BEGIN ATTR_W_TYPE; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 310 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->has_tag = TRUE; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 311 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->encrypted = (guint) strtoul(yytext+8,NULL,10); }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 312 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 313 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{
    /*
     * Support for "ATTRIBUTE name oid type vendor", where the token
     * following the type matches neither has_tag nor encrypt={1,2,3},
     * but is a sequence of digits, lower-case letters, underscores,
     * and hyphens.
     *
     * We mark this as a vendor-specific attribute (VSA), with the token
     * following the type being the vendor name; this notation is deprecated
     * in favor of BEGIN-VENDOR/END-VENDOR blocks.
     */
    gboolean attribute_ok;

    yyextra->attr_vendor = g_strdup(yytext);
    attribute_ok = add_attribute(yyextra, yyextra->attr_name, yyextra->attr_id, yyextra->attr_type, yyextra->attr_vendor, yyextra->encrypted, yyextra->has_tag, yyextra->current_attr);
    g_free(yyextra->attr_id);
    g_free(yyextra->attr_vendor);
    g_free(yyextra->attr_name);
    yyextra->attr_id = NULL;
    yyextra->attr_vendor = NULL;
    yyextra->attr_name = NULL;
    if (attribute_ok)
        BEGIN WS_OUT;
    else
        BEGIN JUNK;
}
	YY_BREAK
case 54:
/* rule 54 can match eol */
YY_RULE_SETUP
#line 339 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{
    add_attribute(yyextra, yyextra->attr_name, yyextra->attr_id, yyextra->attr_type, yyextra->current_vendor, yyextra->encrypted, yyextra->has_tag, yyextra->current_attr);
    g_free(yyextra->attr_id);
    g_free(yyextra->attr_name);
    yyextra->linenums[yyextra->include_stack_ptr]++;
    yyextra->has_tag = FALSE;
    yyextra->encrypted=FALSE;
    BEGIN WS_OUT;
}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 349 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->attr_name = g_strdup(yytext); BEGIN VALUE_W_ATTR; }
	YY_BREAK
case 56:
/* rule 56 can match eol */
YY_RULE_SETUP
#line 350 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->value_repr = g_strdup(yytext); BEGIN VALUE_W_NAME; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 351 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ add_value(yyextra, yyextra->attr_name,yyextra->value_repr, (guint32) strtoul(yytext,NULL,10));  g_free(yyextra->attr_name); g_free(yyextra->value_repr); BEGIN WS_OUT;}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 352 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ add_value(yyextra, yyextra->attr_name,yyextra->value_repr, (guint32) strtoul(yytext,NULL,16));  g_free(yyextra->attr_name); g_free(yyextra->value_repr); BEGIN WS_OUT;}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 354 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{
	if ( yyextra->include_stack_ptr >= MAX_INCLUDE_DEPTH ) {
		g_string_append_printf(yyextra->error, "$INCLUDE files nested too deeply\n");
		yyterminate();
	}

	yyextra->include_stack[yyextra->include_stack_ptr++] = YY_CURRENT_BUFFER;

	yyextra->fullpaths[yyextra->include_stack_ptr] = ws_strdup_printf("%s" G_DIR_SEPARATOR_S "%s",
	    yyextra->directory,yytext);

	yyin = ws_fopen( yyextra->fullpaths[yyextra->include_stack_ptr], "r" );

	if (!yyin) {
		if (errno) {
			g_string_append_printf(yyextra->error,
					"Could not open file: '%s', error: %s\n",
					yyextra->fullpaths[yyextra->include_stack_ptr],
					g_strerror(errno) );
		} else {
			g_string_append_printf(yyextra->error,
					"Could not open file: '%s', no errno\n",
					yyextra->fullpaths[yyextra->include_stack_ptr]);
		}
		g_free(yyextra->fullpaths[yyextra->include_stack_ptr]);
		yyextra->fullpaths[yyextra->include_stack_ptr] = NULL;
		yyextra->include_stack_ptr--;
	} else {
		yyextra->linenums[yyextra->include_stack_ptr] = 1;
		yy_switch_to_buffer(yy_create_buffer(yyin, YY_BUF_SIZE, yyscanner), yyscanner);
	}


	BEGIN WS_OUT;
}
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(WS_OUT):
case YY_STATE_EOF(VENDOR):
case YY_STATE_EOF(VENDOR_W_NAME):
case YY_STATE_EOF(ATTR):
case YY_STATE_EOF(ATTR_W_NAME):
case YY_STATE_EOF(ATTR_W_ID):
case YY_STATE_EOF(ATTR_W_TYPE):
case YY_STATE_EOF(VALUE):
case YY_STATE_EOF(VALUE_W_ATTR):
case YY_STATE_EOF(VALUE_W_NAME):
case YY_STATE_EOF(INCLUDE):
case YY_STATE_EOF(JUNK):
case YY_STATE_EOF(BEGIN_VENDOR):
case YY_STATE_EOF(BEGIN_VENDOR_FORMAT):
case YY_STATE_EOF(END_VENDOR):
case YY_STATE_EOF(VENDOR_W_ID):
case YY_STATE_EOF(VENDOR_W_FORMAT):
case YY_STATE_EOF(VENDOR_W_TYPE_OCTETS):
case YY_STATE_EOF(VENDOR_W_LENGTH_OCTETS):
case YY_STATE_EOF(VENDOR_W_CONTINUATION):
case YY_STATE_EOF(BEGIN_TLV):
case YY_STATE_EOF(END_TLV):
#line 390 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{

	fclose(yyin);
	yyin = NULL;

	if ( --yyextra->include_stack_ptr < 0 ) {
		yyterminate();
	} else {
		g_free(yyextra->fullpaths[yyextra->include_stack_ptr+1]);
		yyextra->fullpaths[yyextra->include_stack_ptr+1] = NULL;

		Radius__delete_buffer(YY_CURRENT_BUFFER, yyscanner);
		Radius__switch_to_buffer(yyextra->include_stack[yyextra->include_stack_ptr], yyscanner);
	}

	BEGIN WS_OUT;
}
	YY_BREAK
case 60:
/* rule 60 can match eol */
YY_RULE_SETUP
#line 408 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
{ yyextra->linenums[yyextra->include_stack_ptr]++; BEGIN WS_OUT; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 411 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"
ECHO;
	YY_BREAK
#line 2171 "radius_dict.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_last_accepting_cpos;
				yy_current_state = yyg->yy_last_accepting_state;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 331 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	char *yy_cp = yyg->yy_c_buf_p;

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 331 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 330);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

#define YYTABLES_NAME "yytables"

#line 411 "/build/wireshark/src/wireshark-4.0.0/epan/radius_dict.l"


/*
 * Turn diagnostics back on, so we check the code that we've written.
 */
DIAG_ON_FLEX

static void add_vendor(Radius_scanner_state_t* state, const gchar* name, guint32 id, guint type_octets, guint length_octets, gboolean has_flags) {
	radius_vendor_info_t* v;

	v = (radius_vendor_info_t *)g_hash_table_lookup(state->dict->vendors_by_id, GUINT_TO_POINTER(id));

	if (!v) {
		/*
		 * New vendor.
		 * Allocate a new entry and insert it into the by-ID and
		 * by-name hash tables.
		 */
		v = g_new(radius_vendor_info_t,1);
		v->attrs_by_id = g_hash_table_new_full(g_direct_hash, g_direct_equal, NULL, free_radius_attr_info);
		v->code = id;
		v->ett = -1;
		v->name = g_strdup(name);
		v->type_octets = type_octets;
		v->length_octets = length_octets;
		v->has_flags = has_flags;

		g_hash_table_insert(state->dict->vendors_by_id,GUINT_TO_POINTER(v->code),v);
		g_hash_table_insert(state->dict->vendors_by_name, (gpointer) v->name, v);
	} else {
		/*
		 * This vendor is already in the table.
		 *
		 * Assume that the dictionary knows the 'ground truth' about
		 * the type/length/has_flags information and thus allow the
		 * dictionary to overwrite these values even for vendors that
		 * have already been loaded.
		 *
		 * XXX - this could be due to the vendor being in multiple
		 * dictionary files, rather than having been specially
		 * entered by the RADIUS dissector, as a side effect of
		 * specially entering an attribute; should we report vendors
		 * that appear in different dictionaries with different
		 * properties?
		 */
		v->type_octets = type_octets;
		v->length_octets = length_octets;
		v->has_flags = has_flags;

		/*
		 * Did the name change?
		 */
		if (g_strcmp0(v->name, name) != 0) {
			/*
			 * Yes.  Remove the entry from the by-name hash table
			 * and re-insert it with the new name.
			 */
			g_hash_table_remove(state->dict->vendors_by_name, (gpointer) v->name);
			g_free((gpointer) v->name);
			v->name = g_strdup(name);
			g_hash_table_insert(state->dict->vendors_by_name, (gpointer) v->name, v);
		}
	}
}

static gboolean add_attribute(Radius_scanner_state_t* state, const gchar* name, const  gchar* codestr, radius_attr_dissector_t type, const  gchar* vendor, guint encrypted_flag, gboolean tagged, const gchar* attr) {
	radius_attr_info_t* a;
	GHashTable* by_id;
	radius_attr_type_t code;
	guint8 code0 = 0, code1 = 0;
	gchar *dot, *buf = NULL;

	if (attr){
		return add_tlv(state, name, codestr, type, attr);
	}

	buf = g_strdup(codestr);
	dot = strchr(codestr, '.');
	if (dot)
		*dot = '\0';
	code0 = (guint8) strtoul(buf, NULL, 10);
	if (dot)
		code1 = (guint8) strtoul(dot + 1, NULL, 10);
	g_free(buf);

	memset(&code, 0, sizeof(code));
	if (vendor) {
		if (state->current_vendor_evs_type) {
			code.u8_code[0] = (guint8) state->current_vendor_evs_type;
			code.u8_code[1] = code0;
		} else {
			code.u8_code[0] = code0;
			code.u8_code[1] = 0;
		}

		radius_vendor_info_t* v = (radius_vendor_info_t *)g_hash_table_lookup(state->dict->vendors_by_name,vendor);
		if (! v) {
			g_string_append_printf(state->error, "Vendor: '%s', does not exist in %s:%i \n", vendor, state->fullpaths[state->include_stack_ptr], state->linenums[state->include_stack_ptr] );
			return FALSE;
		} else {
			by_id = v->attrs_by_id;
		}
	} else {
		code.u8_code[0] = code0;
		code.u8_code[1] = code1;

		by_id = state->dict->attrs_by_id;
	}

	a=(radius_attr_info_t*)g_hash_table_lookup(by_id, GUINT_TO_POINTER(code.value));

	if (!a) {
		/*
		 * New attribute.
		 * Allocate a new entry and insert it into the by-ID and
		 * by-name hash tables.
		 */
		a = g_new(radius_attr_info_t,1);
		a->code = code;
		a->name = g_strdup(name);
		a->dissector = NULL;
		a->encrypt = encrypted_flag;
		a->tagged =  tagged;
		a->type = type;
		a->vs = NULL;
		a->hf = -1;
		a->hf_alt = -1;
		a->hf_tag = -1;
		a->hf_len = -1;
		a->ett = -1;
		a->tlvs_by_id = NULL;
		g_hash_table_insert(by_id, GUINT_TO_POINTER(code.value),a);
		g_hash_table_insert(state->dict->attrs_by_name,(gpointer) (a->name),a);
	} else {
		/*
		 * This attribute is already in the table.
		 *
		 * Overwrite the encrypted flag, tagged property, and type;
		 * the other properties don't get set until after we've
		 * finished reading the dictionaries.
		 *
		 * XXX - this could be due to the attribute being in
		 * multiple dictionary files, rather than having been
		 * specially entered by the RADIUS dissector to give it
		 * a special dissection routine; should we report attributes
		 * that appear in different dictionaries with different
		 * properties?
		 */
		a->encrypt = encrypted_flag;
		a->tagged =  tagged;
		a->type = type;

		/*
		 * Did the name change?
		 */
		if (g_strcmp0(a->name, name) != 0) {
			/*
			 * Yes.  Steal the entry from the by-name hash table
			 * and re-insert it with the new name.  (Don't
			 * remove it - that calls the free routine, which
			 * frees up the entry.)
			 */
			g_hash_table_steal(state->dict->attrs_by_name, (gpointer) (a->name));
			g_free((gpointer) a->name);
			a->name = g_strdup(name);
			g_hash_table_insert(state->dict->attrs_by_name, (gpointer) (a->name),a);
		}
	}
	return TRUE;
}

static gboolean add_tlv(Radius_scanner_state_t* state, const gchar* name, const  gchar* codestr, radius_attr_dissector_t type, const gchar* attr) {
	radius_attr_info_t* a;
	radius_attr_info_t* s;
	radius_attr_type_t code;

	a = (radius_attr_info_t*)g_hash_table_lookup(state->dict->attrs_by_name, attr);

	if (! a) {
		g_string_append_printf(state->error, "Attr: '%s', does not exist in %s:%i \n", attr, state->fullpaths[state->include_stack_ptr], state->linenums[state->include_stack_ptr]);
		return FALSE;
	}

	if (type == radius_tlv) {
		g_string_append_printf(state->error, "sub-TLV: '%s', sub-TLV's type is specified as tlv in %s:%i \n", name, state->fullpaths[state->include_stack_ptr], state->linenums[state->include_stack_ptr]);
		return FALSE;
	}


	if (! a->tlvs_by_id) {
		a->tlvs_by_id = g_hash_table_new_full(g_direct_hash, g_direct_equal, NULL, free_radius_attr_info);
	}

	memset(&code, 0, sizeof(code));
	code.u8_code[0] = (guint8) strtoul(codestr, NULL, 10);

	s = (radius_attr_info_t*)g_hash_table_lookup(a->tlvs_by_id, GUINT_TO_POINTER(code.value));

	if (!s) {
		/*
		 * This TLV doesn't yet exist in this attribute's TLVs-by-ID
		 * hash table.  Add it.
		 */
		s = g_new(radius_attr_info_t,1);
		s->name = g_strdup(name);
		s->dissector = NULL;
		s->code = code;
		s->type = type;
		s->encrypt = FALSE;
		s->tagged = FALSE;
		s->dissector = NULL;
		s->vs = NULL;
		s->hf = -1;
		s->hf_alt = -1;
		s->hf_tag = -1;
		s->hf_len = -1;
		s->ett = -1;
		s->tlvs_by_id = NULL;

		g_hash_table_insert(a->tlvs_by_id,GUINT_TO_POINTER(s->code.value),s);
		g_hash_table_insert(state->dict->tlvs_by_name,(gpointer) (s->name),s);
	}

	/*
	 * If it *does* exist, leave it alone; there shouldn't be duplicate
	 * entries by name in the dictionaries (even if there might be
	 * multiple entries for a given attribute in the dictionaries, each
	 * one adding some TLV values), and we don't directly add entries
	 * for TLVs in the RADIUS dissector.
	 *
	 * XXX - report the duplicate entries?
	 */
	return TRUE;
}

void add_value(Radius_scanner_state_t* state, const gchar* attrib_name, const gchar* repr, guint32 value) {
	value_string v;
	GArray* a = (GArray*)g_hash_table_lookup(state->value_strings,attrib_name);

	if (! a) {
		/* Ensure that the array is zero terminated. */
		a = g_array_new(TRUE, TRUE, sizeof(value_string));
		g_hash_table_insert(state->value_strings, g_strdup(attrib_name), a);
	}

	v.value = value;
	v.strptr = g_strdup(repr);

	g_array_append_val(a,v);
}

static void setup_tlvs(gpointer k _U_, gpointer v, gpointer p) {
	radius_attr_info_t* s = (radius_attr_info_t*)v;
	Radius_scanner_state_t* state = (Radius_scanner_state_t*)p;
	gpointer key;

	union {
		GArray* a;
		gpointer p;
	} vs;

	if (g_hash_table_lookup_extended(state->value_strings, s->name, &key, &vs.p)) {
		g_hash_table_steal(state->value_strings, key);
		s->vs = (value_string*)(void *)g_array_free(vs.a, FALSE);
		g_free(key);
	}
}

static void setup_attrs(gpointer k _U_, gpointer v, gpointer p) {
	radius_attr_info_t* a = (radius_attr_info_t*)v;
	Radius_scanner_state_t* state = (Radius_scanner_state_t*)p;
	gpointer key;

	union {
		GArray* a;
		gpointer p;
	} vs;

	if (g_hash_table_lookup_extended(state->value_strings, a->name, &key, &vs.p) ) {
		g_hash_table_steal(state->value_strings, key);
		a->vs = (value_string*)(void *)g_array_free(vs.a, FALSE);
		g_free(key);
	}

	if (a->tlvs_by_id) {
		g_hash_table_foreach(a->tlvs_by_id, setup_tlvs, p);
	}
}

static void setup_vendors(gpointer k _U_, gpointer v, gpointer p) {
	radius_vendor_info_t* vnd = (radius_vendor_info_t*)v;

	g_hash_table_foreach(vnd->attrs_by_id,setup_attrs,p);
}

static void destroy_value_strings(gpointer v) {
	value_string* vs = (value_string*)(void *)(((GArray*)v)->data);

	for (;vs->strptr;vs++) {
		g_free((void*)vs->strptr);
	}

	g_array_free((GArray*)v,TRUE);
}

gboolean radius_load_dictionary (radius_dictionary_t* d, gchar* dir, const gchar* filename, gchar** err_str) {
	FILE *in;
	yyscan_t scanner;
	Radius_scanner_state_t state;
	int i;

	state.include_stack_ptr = 0;

	state.dict = d;
	state.value_strings = NULL;

	state.attr_name = NULL;
	state.attr_id = NULL;
	state.attr_type = NULL;
	state.attr_vendor = NULL;
	state.vendor_name = NULL;
	state.vendor_id = 0;
	state.vendor_type_octets = 1;
	state.vendor_length_octets = 1;
	state.vendor_has_flags = FALSE;
	state.value_repr = NULL;
	state.encrypted = 0;
	state.has_tag = FALSE;
	state.current_vendor = NULL;
	state.current_vendor_evs_type = 0;
	state.current_attr = NULL;

	state.directory = dir;

	state.fullpaths[0] = ws_strdup_printf("%s" G_DIR_SEPARATOR_S "%s",
	    state.directory,filename);
	state.linenums[0] = 1;
	for (i = 1; i < MAX_INCLUDE_DEPTH; i++) {
		state.fullpaths[i] = NULL;
		state.linenums[i] = 1;
	}

	state.error = g_string_new("");

	in = ws_fopen(state.fullpaths[0],"r");

	if (!in) {
		g_string_append_printf(state.error, "Could not open file: '%s', error: %s\n", state.fullpaths[0], g_strerror(errno));
		g_free(state.fullpaths[0]);
		*err_str = g_string_free(state.error,FALSE);
		return FALSE;
	}

	state.value_strings = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, destroy_value_strings);

	if (Radius_lex_init(&scanner) != 0) {
		g_string_append_printf(state.error, "Can't initialize scanner: %s",
		    strerror(errno));
		fclose(in);
		g_free(state.fullpaths[0]);
		*err_str = g_string_free(state.error,FALSE);
		return FALSE;
	}

	Radius_set_in(in, scanner);

	/* Associate the state with the scanner */
	Radius_set_extra(&state, scanner);

	Radius_lex(scanner);

	Radius_lex_destroy(scanner);
	/*
	 * XXX - can the lexical analyzer terminate without closing
	 * all open input files?
	 */

	for (i = 0; i < MAX_INCLUDE_DEPTH; i++) {
		g_free(state.fullpaths[i]);
	}

	g_hash_table_foreach(state.dict->attrs_by_id,setup_attrs,&state);
	g_hash_table_foreach(state.dict->vendors_by_id,setup_vendors,&state);
	g_hash_table_destroy(state.value_strings);

	if (state.error->len > 0) {
		*err_str = g_string_free(state.error,FALSE);
		return FALSE;
	} else {
		*err_str = NULL;
		g_string_free(state.error,TRUE);
		return TRUE;
	}
}

/*
 * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
 *
 * Local variables:
 * c-basic-offset: 8
 * tab-width: 8
 * indent-tabs-mode: t
 * End:
 *
 * vi: set shiftwidth=8 tabstop=8 noexpandtab:
 * :indentSize=8:tabSize=8:noTabs=false:
 */

